@@ -2,14 +2,13 @@
 
 #![cfg_attr(not(debug_assertions), windows_subsystem = "windows")]
 
-extern crate rfd;
+extern crate nfd;
 extern crate sixtyfps;
 
-use rfd::FileDialog;
 use sixtyfps::{Model, ModelHandle, SharedString};
 use std::collections::HashMap;
 use std::fmt::Debug;
-use std::path::{Path, PathBuf};
+use std::path::Path;
 use std::rc::Rc;
 use std::sync::Mutex;
 use std::thread;
@@ -74,11 +73,7 @@ impl MainWindow {
         let settings: Settings =
             JsonPersistence::load(&get_settings_filename()).unwrap_or_else(Settings::new);
 
-        let item_list = ItemList {
-            items: vec![],
-            events: vec![],
-            path: PathBuf::new(),
-        };
+        let item_list = ItemList::new();
 
         let item_list = Arc::new(Mutex::new(item_list));
 
@@ -236,8 +231,13 @@ impl MainWindow {
             let synchronizer = self.synchronizer.clone();
 
             move || {
-                let file_dialog = FileDialog::new();
-                if let Some(folder) = file_dialog.pick_folder() {
+                if let Ok(nfd::Response::Okay(folder)) = nfd::open_pick_folder(Some(
+                    window_weak
+                        .unwrap()
+                        .get_source_directory()
+                        .to_string()
+                        .as_str(),
+                )) {
                     {
                         // Save current item list
                         let item_list = item_list.lock().unwrap();
@@ -254,12 +254,14 @@ impl MainWindow {
 
                     // Synchronize in a background thread
                     window_weak.unwrap().set_loading(true);
-                    synchronizer
-                        .synchronize(Some(&folder), Settings::from_window(&window_weak.unwrap()));
+                    synchronizer.synchronize(
+                        Some(Path::new(&folder)),
+                        Settings::from_window(&window_weak.unwrap()),
+                    );
 
                     window_weak
                         .unwrap()
-                        .set_source_directory(SharedString::from(folder.to_str().unwrap()));
+                        .set_source_directory(SharedString::from(folder));
                 }
             }
         });
@@ -269,13 +271,16 @@ impl MainWindow {
             let window_weak = self.window.as_weak();
 
             move || {
-                let file_dialog = FileDialog::new();
-                if let Some(folder) = file_dialog.pick_folder() {
-                    let target_path = &String::from(folder.to_str().unwrap());
-
+                if let Ok(nfd::Response::Okay(folder)) = nfd::open_pick_folder(Some(
                     window_weak
                         .unwrap()
-                        .set_target_directory(SharedString::from(target_path));
+                        .get_target_directory()
+                        .to_string()
+                        .as_str(),
+                )) {
+                    window_weak
+                        .unwrap()
+                        .set_target_directory(SharedString::from(folder));
                 }
             }
         });
