@@ -19,6 +19,8 @@ pub type DoneCallback = Box<dyn Fn(ImageBuffer) + Send + 'static>;
 /// The command sent to the load thread for a new image
 pub type LoadImageCommand = (FileItem, u32, u32, Option<DoneCallback>);
 
+const HOURGLASS_PNG: &[u8; 5533] = include_bytes!("hourglass.png");
+
 /// Purpose of the image to load from the cache
 pub enum Purpose {
     /// The image is the currently selected image and needs to be loaded as soon as possible
@@ -38,8 +40,6 @@ pub enum Purpose {
 pub struct ImageCache {
     /// Map with the images
     images: Arc<ImagesMapMutex>,
-    /// Buffered image showing a video camera to be used when the file is not an image
-    video_image: Image,
     /// Buffered image to be displayed while waiting for an image to load
     waiting_image: Image,
     /// Maximum width of the images to load
@@ -76,7 +76,6 @@ impl ImageCache {
 
         Self {
             images: mutex,
-            video_image: ImageCache::get_video(),
             waiting_image: ImageCache::get_hourglass(),
             max_width: 0,
             max_height: 0,
@@ -90,18 +89,8 @@ impl ImageCache {
     /// Gets the hourglass image to indicate waiting
     /// The image is compiled into the binary
     fn get_hourglass() -> Image {
-        let bytes = include_bytes!("hourglass.png");
         crate::misc::images::get_sixtyfps_image(
-            &crate::misc::images::image_from_buffer(bytes).unwrap(),
-        )
-    }
-
-    /// Gets the video image to indicate that the file is not an image
-    /// The image is compiled into the binary
-    fn get_video() -> Image {
-        let bytes = include_bytes!("video.png");
-        crate::misc::images::get_sixtyfps_image(
-            &crate::misc::images::image_from_buffer(bytes).unwrap(),
+            &crate::misc::images::image_from_buffer(HOURGLASS_PNG).unwrap(),
         )
     }
 
@@ -116,14 +105,10 @@ impl ImageCache {
 
     /// Gets an image from the cache
     pub fn get(&self, item: &FileItem) -> Option<Image> {
-        if item.is_image() {
-            let item_path = item.path.to_str().unwrap();
-            let mut map = self.images.lock().unwrap();
-            map.get(String::from(item_path))
-                .map(|image| crate::misc::images::get_sixtyfps_image(image))
-        } else {
-            Some(self.video_image.clone())
-        }
+        let item_path = item.path.to_str().unwrap();
+        let mut map = self.images.lock().unwrap();
+        map.get(String::from(item_path))
+            .map(|image| crate::misc::images::get_sixtyfps_image(image))
     }
 
     /// Gets the waiting image
@@ -178,8 +163,11 @@ fn load_image_thread(
         };
         // If it is not in the cache, load it from the file and put it into the cache
         if !contains_key {
-            let image_buffer =
-                crate::misc::images::get_image_buffer(&prefetch_item, max_width, max_height);
+            let image_buffer = if prefetch_item.is_image() {
+                crate::misc::images::get_image_buffer(&prefetch_item, max_width, max_height)
+            } else {
+                crate::misc::video_to_image::get_image_buffer(&prefetch_item, max_width, max_height)
+            };
             let mut map = cache.lock().unwrap();
             map.put(String::from(item_path), image_buffer.clone());
         }
